Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5515)

Unified Diff: chrome/browser/sync/test/integration/apps_helper.h

Issue 1851243002: [Sync] Eliminate verifier profile from sync_integration_tests (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: do not remove AwaitQuiescence() Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/sync/test/integration/apps_helper.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/sync/test/integration/apps_helper.h
diff --git a/chrome/browser/sync/test/integration/apps_helper.h b/chrome/browser/sync/test/integration/apps_helper.h
index 27567e38f0781e6bd142318f59bb533f349bffc1..1fba033b7128e8c3c1988b7e80851a9e25d2fc32 100644
--- a/chrome/browser/sync/test/integration/apps_helper.h
+++ b/chrome/browser/sync/test/integration/apps_helper.h
@@ -13,13 +13,13 @@ class Profile;
namespace apps_helper {
-// Returns true iff the profile with index |index| has the same apps (hosted,
-// legacy packaged and platform) as the verifier.
-bool HasSameAppsAsVerifier(int index) WARN_UNUSED_RESULT;
+// Returns true iff |profile1| has same apps (hosted, legacy packaged and
+// platform) as |profile2|.
+bool HasSameApps(Profile* profile1, Profile* profile2);
// Returns true iff all existing profiles have the same apps (hosted,
-// legacy packaged and platform) as the verifier.
-bool AllProfilesHaveSameAppsAsVerifier() WARN_UNUSED_RESULT;
+// legacy packaged and platform).
+bool AllProfilesHaveSameApps() WARN_UNUSED_RESULT;
// Installs the app for the given index to |profile|, and returns the extension
// ID of the new app.
@@ -47,12 +47,19 @@ void EnableApp(Profile* profile, int index);
// Disables the app for the given index on |profile|.
void DisableApp(Profile* profile, int index);
+// Returns true if the app with index |index| is enabled on |profile|.
+bool IsAppEnabled(Profile* profile, int index);
+
// Enables the app for the given index in incognito mode on |profile|.
void IncognitoEnableApp(Profile* profile, int index);
// Disables the app for the given index in incognito mode on |profile|.
void IncognitoDisableApp(Profile* profile, int index);
+// Returns true if the app with index |index| is enabled in incognito mode on
+// |profile|.
+bool IsIncognitoEnabled(Profile* profile, int index);
+
// Gets the page ordinal value for the application at the given index on
// |profile|.
syncer::StringOrdinal GetPageOrdinalForApp(Profile* profile, int app_index);
« no previous file with comments | « no previous file | chrome/browser/sync/test/integration/apps_helper.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698